import MHeader from '@/components/m-header';
import { defineComponent, onMounted, reactive } from 'vue';
import {
  Button,
  Cell,
  CellGroup,
  Field,
  Image,
  Popup,
  Radio,
  RadioGroup,
  Tag,
  showToast
} from 'vant';
import styles from './index.module.less';
import iconRefunding from './images/icon_refunding.svg';
import icon_success from './images/icon_success.svg';
import iconClose from './images/icon_close.svg';
import iconTradeing from './images/icon_tradeing.svg';
import { useRoute, useRouter } from 'vue-router';
import { browser, moneyFormat } from '@/helpers/utils';
import { useEventListener, useWindowScroll } from '@vueuse/core';
import {
  api_userPaymentOrderCancelRefund,
  api_userPaymentOrderDetail,
  api_userPaymentOrderRefundDetail,
  api_userPaymentOrderRefundPayment
} from '../collection-record/api';
import * as detailState from '@/state';

export default defineComponent({
  name: 'collection-record-detail',
  setup() {
    const route = useRoute();
    const router = useRouter();
    const state = reactive({
      refundAudit: '' as any, // 退回审核状态
      refundOrderId: '', // 退回订单id
      orders: {} as any,
      goodsInfos: [] as any,
      background: 'transparent',
      color: '#fff',
      backIconColor: 'white' as any,
      timer: null as any,
      timerCount: 0 // 执行次数
    });
    const getDetails = async () => {
      try {
        if (!route.query.orderNo) return;
        const res = await api_userPaymentOrderRefundDetail(route.query.orderNo);
        if (res?.code !== 200) return;
        state.orders = res.data.order || {};
        const tempGoods = res.data.order.goodsInfos || [];
        tempGoods.forEach((item: any) => {
          const img = item.goodsUrl ? item.goodsUrl.split(',')[0] : '';
          item.goodsUrl = img;
        });
        state.goodsInfos = tempGoods;
        if (Array.isArray(res.data?.refund)) {
          const refunds = res.data.refund;
          const index = refunds.length - 1;
          state.refundAudit = refunds[index]?.refundAudit || '';
          state.refundOrderId = refunds[index]?.id || '';
          if (state.refundAudit === 'ING') {
            state.orders.status = 'REFUNDING';
          } else if (state.refundAudit === 'PASS') {
            state.orders.status = 'REFUNDED';
          }
        }
      } catch {
        //
      }
    };

    // 定时任务
    const onTimeout = async () => {
      // 判断订单状态，如果未支付则刷新
      if (
        ['WAIT_PAY', 'PAYING'].includes(state.orders.status) &&
        state.timerCount <= 10
      ) {
        state.timer = setTimeout(async () => {
          state.timerCount += 1;
          await getDetails();
          onTimeout();
        }, 3000);
      } else {
        clearTimeout(state.timer);
      }
    };

    const formatImg = (type: any) => {
      const template: any = {
        WAIT_PAY: iconTradeing,
        PAYING: iconTradeing,
        PAID: icon_success,
        TIMEOUT: iconClose,
        FAIL: iconClose,
        CLOSED: iconClose,
        REFUNDING: iconRefunding,
        REFUNDED: icon_success
      };
      return template[type] || icon_success;
    };

    const formatOrderStatus = (status: string) => {
      const temp: any = {
        WAIT_PAY: '领取中',
        PAYING: '领取中',
        PAID: '领取成功',
        TIMEOUT: '订单超时',
        FAIL: '领取失败',
        CLOSED: '已关闭',
        REFUNDING: '退回申请中',
        REFUNDED: '已退回'
      };
      return temp[status];
    };

    onMounted(async () => {
      await getDetails();
      await onTimeout();
      useEventListener(document, 'scroll', () => {
        const { y } = useWindowScroll();
        if (y.value > 52) {
          state.background = '#fff';
          state.color = '#323333';
          state.backIconColor = 'black';
        } else {
          state.background = 'transparent';
          state.color = '#fff';
          state.backIconColor = 'white';
        }
      });
    });

    /** 取消退款申请 */
    const handleBack = async () => {
      await api_userPaymentOrderCancelRefund(state.refundOrderId);
      showToast('撤销退回成功');
      await getDetails();
    };
    return () => (
      <div class={styles.paymentResult}>
        <div class={[styles.paymentTitle]}>
          <MHeader background="transparent" />

          {state.orders.id && (
            <>
              <div class={styles.orderType}>
                <Image
                  class={styles.img}
                  src={formatImg(state.orders.status)}
                />
                <div class={styles.orderInfo}>
                  <span>{formatOrderStatus(state.orders.status)}</span>
                  {state.orders.status === 'PAID' ? (
                    <div class={styles.orderPrice}>
                      实付金额：￥ {moneyFormat(state.orders.paymentCashAmount)}
                    </div>
                  ) : (
                    ''
                  )}

                  {['REFUNDING', 'REFUNDED'].includes(state.orders.status) && (
                    <div class={styles.orderPrice}>
                      退回金额：￥ {moneyFormat(state.orders.paymentCashAmount)}
                    </div>
                  )}
                </div>
              </div>
            </>
          )}
        </div>

        <CellGroup inset class={[styles.cellGroup, styles.mTop]}>
          <Cell>
            {{
              title: () => '付款时间',
              value: () => <span>{state.orders.payTime || '--'}</span>
            }}
          </Cell>
          <Cell>
            {{
              title: () => '订单编号',
              value: () => <span>{state.orders.orderNo}</span>
            }}
          </Cell>
        </CellGroup>

        <CellGroup inset class={styles.cellGroup}>
          <div class={styles.buyDetail}>
            <div class={styles.buyDetailTitle}>
              <i></i> 购买详情
            </div>
          </div>
          {state.goodsInfos.map((goods: any) => (
            <Cell>
              {{
                icon: () => (
                  <Image class={styles.buyImg} src={goods.goodsUrl} />
                ),
                title: () => (
                  <div class={styles.buyContent}>
                    <p class={styles.goodsTitle}>{goods.goodsName}</p>
                    <Tag class={styles.brandName}>
                      {state.orders.orderType === 'VIP'
                        ? '12个月'
                        : goods.brandName}
                    </Tag>
                  </div>
                ),
                value: () => <span>x {goods.goodsNum}</span>
              }}
            </Cell>
          ))}
        </CellGroup>

        {state.refundAudit === 'ING' && (
          <Button
            class={styles.cancelBtn}
            block
            round
            type="primary"
            onClick={() => handleBack()}>
            撤销退回
          </Button>
        )}
      </div>
    );
  }
});
